#ifndef NT2_INCLUDE_FUNCTIONS_ISSQUARE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISSQUARE_HPP_INCLUDED

#include <nt2/predicates/include/functions/issquare.hpp>

#endif
